==> monitoring-deployer-v0.2-sources.jar: com/ebmwebsourcing/seacloud/deployer/MonitoringDeployerModule.java <==
package com.ebmwebsourcing.seacloud.deployer;

import java.net.MalformedURLException;
import java.net.URL;
import java.util.List;

import javax.xml.namespace.QName;

import seacloud.petalslink.com.service.management.cloud._1_0.CloudManagementException;

import com.ebmwebsourcing.easierbsm.admin.client.api.BSMAdminClient;
import com.ebmwebsourcing.easierbsm.admin.client.impl.BSMAdminClientImpl;
import com.ebmwebsourcing.easyesb.soa.api.ESBException;
import com.ebmwebsourcing.seacloud.model.AbstractModule;
import com.ebmwebsourcing.seacloud.model.AdvancedESBModule;
import com.ebmwebsourcing.seacloud.model.DeployerModule;

import easierbsm.petalslink.com.data.bsmadmin._1.LoadAgreementFromUrlRequest;
import easybox.esstar.petalslink.com.management.model.datatype._1.EJaxbDeploy;
import easybox.esstar.petalslink.com.management.model.datatype._1.EJaxbDeployResponse;
import easybox.esstar.petalslink.com.management.model.datatype._1.EJaxbDeployementReport;
import esstar.petalslink.com.data.management.user._1.Bind;
import esstar.petalslink.com.data.management.user._1.BindResponse;
import esstar.petalslink.com.data.management.user._1.Proxify;
import esstar.petalslink.com.data.management.user._1.ProxifyResponse;
import esstar.petalslink.com.service.management._1_0.ManagementException;

public class MonitoringDeployerModule extends AbstractModule implements DeployerModule, AdvancedESBModule {

	private BSMAdminClient client = null;

	public MonitoringDeployerModule(List<URL> adminAdresses) throws CloudManagementException {
		super(adminAdresses);

		if(this.externalComponentAdresses.size() > 0) {
			try {
				this.client = new BSMAdminClientImpl(this.externalComponentAdresses.get(0).toString());
			} catch (ESBException e) {
				throw new CloudManagementException(e.getMessage(), e);
			}
		}
	}

	/**
	 * @return the clientProxy
	 */
	private synchronized BSMAdminClient getClientProxy() {
		return this.client;
	}

	@Override
	public EJaxbDeployResponse deploy(EJaxbDeploy parameters)
			throws CloudManagementException {
		try {
			System.out.println("--------- DEPLOY");
			System.out.println("--------- LOAD Agreement: " + parameters.getMainResource().getFileURI());
			LoadAgreementFromUrlRequest request = new LoadAgreementFromUrlRequest();
			request.setUrl(parameters.getMainResource().getFileURI());
			this.getClientProxy().loadAgreementFromUrl(request);
			EJaxbDeployResponse resp = new EJaxbDeployResponse();
			return resp;
		} catch (Exception e) {
			throw new CloudManagementException(e.getMessage(), e);
		}
	}

	@Override
	public BindResponse bind(Bind parameters) throws CloudManagementException {
		throw new UnsupportedOperationException();
	}

	@Override
	public String expose(QName serviceName, String endpointName)
			throws CloudManagementException {
		throw new UnsupportedOperationException();
	}

	@Override
	public ProxifyResponse proxify(Proxify parameters)
			throws CloudManagementException {
		throw new UnsupportedOperationException();
	}

}

==> monitoring-deployer-v0.4-sources.jar: com/ebmwebsourcing/seacloud/deployer/MonitoringDeployerModule.java <==
package com.ebmwebsourcing.seacloud.deployer;

import java.net.URL;
import java.util.List;

import javax.xml.namespace.QName;

import org.w3c.dom.Document;

import seacloud.petalslink.com.service.management.cloud._1_0.CloudManagementException;

import com.ebmwebsourcing.easierbsm.admin.client.api.BSMAdminClient;
import com.ebmwebsourcing.easierbsm.admin.client.impl.BSMAdminClientImpl;
import com.ebmwebsourcing.easierbsm.admin.client.impl.BSMAdminClientImplSOAP;
import com.ebmwebsourcing.easycommons.research.util.dom.DOMUtil;
import com.ebmwebsourcing.easycommons.research.util.jaxb.SOAJAXBContext;
import com.ebmwebsourcing.easyesb.soa.api.ESBException;
import com.ebmwebsourcing.seacloud.model.AbstractModule;
import com.ebmwebsourcing.seacloud.model.AdvancedESBModule;
import com.ebmwebsourcing.seacloud.model.DeployerModule;

import easierbsm.petalslink.com.data.bsmadmin._1.LoadAgreementFromUrlRequest;
import easierbsm.petalslink.com.data.bsmadmin._1.LoadAgreementRequest;
import easybox.esstar.petalslink.com.management.model.datatype._1.EJaxbDeploy;
import easybox.esstar.petalslink.com.management.model.datatype._1.EJaxbDeployResponse;
import easybox.org.ggf.schemas.graap._2007._03.ws_agreement.EJaxbAgreementType;
import esstar.petalslink.com.data.management.user._1.Bind;
import esstar.petalslink.com.data.management.user._1.BindResponse;
import esstar.petalslink.com.data.management.user._1.Proxify;
import esstar.petalslink.com.data.management.user._1.ProxifyResponse;

public class MonitoringDeployerModule extends AbstractModule implements DeployerModule, AdvancedESBModule {

	private BSMAdminClient client = null;
	
	static {
		try {
			SOAJAXBContext.getInstance().addOtherObjectFactory(
					easybox.org.ggf.schemas.graap._2007._03.ws_agreement.ObjectFactory.class,
					easybox.org.w3._2005._08.addressing.ObjectFactory.class);
		} catch(Exception e) {
			// do nothing
		}
	}

	public MonitoringDeployerModule(List<URL> adminAdresses) throws CloudManagementException {
		super(adminAdresses);

		if(this.externalComponentAdresses.size() > 0) {
			try {
				this.client = new BSMAdminClientImplSOAP(this.externalComponentAdresses.get(0).toString());
			} catch (ESBException e) {
				throw new CloudManagementException(e.getMessage(), e);
			}
		}
	}

	/**
	 * @return the clientProxy
	 */
	private synchronized BSMAdminClient getClientProxy() {
		return this.client;
	}

	@Override
	public EJaxbDeployResponse deploy(EJaxbDeploy parameters)
			throws CloudManagementException {
		try {
			System.out.println("--------- DEPLOY");
			System.out.println("--------- LOAD Agreement: " + parameters.getMainResource().getFileURI());
			if(parameters.getMainResource().getAttachment().getInputStream() != null) {
				Document doc = DOMUtil.getInstance().getDocumentBuilderFactory().newDocumentBuilder().parse(parameters.getMainResource().getAttachment().getInputStream());
				LoadAgreementRequest request = new LoadAgreementRequest();
				request.setAgreement(SOAJAXBContext.getInstance().marshallAnyType(doc, EJaxbAgreementType.class));
				this.getClientProxy().loadAgreementFromDocument(request);
			} else {
				LoadAgreementFromUrlRequest request = new LoadAgreementFromUrlRequest();
				request.setUrl(parameters.getMainResource().getFileURI());
				this.getClientProxy().loadAgreementFromUrl(request);
			}
			
			
			EJaxbDeployResponse resp = new EJaxbDeployResponse();
			return resp;
		} catch (Exception e) {
			throw new CloudManagementException(e.getMessage(), e);
		}
	}
	


	@Override
	public BindResponse bind(Bind parameters) throws CloudManagementException {
		throw new UnsupportedOperationException();
	}

	@Override
	public String expose(QName serviceName, String endpointName)
			throws CloudManagementException {
		throw new UnsupportedOperationException();
	}

	@Override
	public ProxifyResponse proxify(Proxify parameters)
			throws CloudManagementException {
		throw new UnsupportedOperationException();
	}

}
